@@ -36,6 +36,7 @@ class UWC_Cache {
   var $action="";
   var $cache_action="";
   var $lang="";
+  var $lang_forced=false;
   var $file="";
   var $http_code=0;
 
@@ -104,6 +105,7 @@ class UWC_Cache {
   function update_lang() {
     $this->lang->set_accepted_lang(array());
     if ($this->request->has_key("lang")) {
+      $this->lang_forced=true;
       $this->lang->set_lang_id($this->request->get_value("lang"));
     }
   }
@@ -167,11 +169,12 @@ class UWC_Cache {
 			  $http_code,
 			  preg_replace("/\\//",",",$this->path));
     } else {
-      $this->file=sprintf("%s/_uwikicms/cache/%s%s-%s.%s.html",
+      $this->file=sprintf("%s/_uwikicms/cache/%s%s-%s-%s.%s.html",
 			  $this->conf->prefix,
 			  $http_code,
 			  preg_replace("/\\//",",",$this->path),
 			  $this->action,
+			  $this->lang_forced ? "i18n" : "default",
 			  $this->lang->get_lang_id());
     }
   }
