@@ -557,11 +557,11 @@ class UWC_Page {
   }
 
   function get_image_preview_url() {
-    return $this->make_url(uwc_image_make_preview_url(uwc_content_get_parent_path($this->path),$this->context->get_image_id()));
+    return $this->make_url(uwc_image_make_preview_url(uwc_content_get_parent_path($this->get_path()),$this->context->get_image_id()));
   }
 
   function get_image_full_url() {
-    return $this->make_url(uwc_image_make_full_url(uwc_content_get_parent_path($this->path),$this->context->get_image_id()));
+    return $this->make_url(uwc_image_make_full_url(uwc_content_get_parent_path($this->get_path()),$this->context->get_image_id()));
   }
 
   function get_image_preview_w() {
@@ -854,7 +854,7 @@ class UWC_Page {
   }
 
   function need_action_allinone() {
-    return ($this->context->action=="view" || $this->context->action=="tree") && $this->auth->can_admin() && $this->viewable();
+    return ($this->context->action=="view" || $this->context->action=="tree" || $this->context->action="external") && $this->auth->can_admin() && $this->viewable();
   }
 
   function need_action_new() {
